<?php
require_once 'lib/user_input_handler_registry.php';
//require_once 'language.php';

class IzhcomPurchaseHandler implements UserInputHandler {
	private $session;
	
	public function __construct($session) {
    	$this->session = $session;
        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }

    public function get_handler_id() {
        return 'purchase';
    }

    public function handle_user_input(&$user_input, &$plugin_cookies) {
    	$this->session->check_logged_in($plugin_cookies);
    	
    	$movie_id = ( isset($plugin_cookies->current_movie_id) && $plugin_cookies->current_movie_id ) ? intval( $plugin_cookies->current_movie_id ) : '';
		$plugin_cookies->current_movie_id = '';
    	
    	if( $user_input->control_id != 'make_purchase' || !$movie_id ) return;
    	
    	$status = $this->session->purchase_content( $movie_id, false, $plugin_cookies );
    	hd_print(__FUNCTION__ . ': status=' . $status);
    	
	   	if($status === 0) {
			// purchased now, show message
			$action = ActionFactory::show_error( false, TEXT_IZHTV_TITLE, explode("\n", TEXT_MOVIE_PURCHASED ) );

		} elseif($status == -10) { // as movie not found
			$this->set_failed_movie_id( $movie_id );
			$action = ActionFactory::show_error( false, TEXT_IZHTV_TITLE . ' : ' . TITLE_SERVER_ERROR, array(TEXT_MOVIE_NOT_FOUND) );

    	} elseif($status == -11) { //  no money
			$action = ActionFactory::show_error( false, TEXT_IZHTV_TITLE, array(TEXT_NO_MONEY) );
    	
    	} else { // default error hanler
			$action = ActionFactory::show_error( false, TEXT_IZHTV_TITLE . ' : ' . TITLE_SERVER_ERROR, explode("\n", TEXT_NO_CONNECTION) );
    	}

		return( ActionFactory::close_dialog_and_run( $action ) );
    }
	
}

class IzhcomEntryHandler implements UserInputHandler {

	private $session;

    public function __construct($session) {
    	$this->session = $session;
        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }

    public function get_handler_id() {
        return 'entry';
    }

    public function handle_user_input(&$user_input, &$plugin_cookies) {

        hd_print('Entry handler: handle_user_input:');
        foreach ($user_input as $key => $value) hd_print("  $key => $value");

		if (!isset($user_input->entry_id)) return null;

        $add_params = array( 'entry_id' => $user_input->entry_id );

        	$auth_state = 0;
	        $r = $this->session->do_auth($user_input, $plugin_cookies, $auth_state);
        
    	    if($r === true) {
        		if ( isset($user_input->control_id) )
        			return ActionFactory::close_dialog_and_run(ActionFactory::open_folder());
       		
	       		return( ActionFactory::open_folder() );
    	    } 
        
    	    if($auth_state == -4) {
				if( isset($user_input->control_id) )
	        		return ActionFactory::close_dialog_and_run( 
    	    				ActionFactory::show_error( true, TEXT_IZHTV_TITLE . ' : ' . TITLE_AUTH_ERROR, explode("\n", TEXT_NO_CONNECTION) ) 
					);	

				return ActionFactory::show_error( true, TEXT_IZHTV_TITLE . ' : ' . TITLE_AUTH_ERROR, explode("\n", TEXT_NO_CONNECTION) );
			}
        
    	    if( isset($user_input->control_id) ) {
				return ActionFactory::close_dialog_and_run( 
        			ActionFactory::show_error( true, TEXT_IZHTV_TITLE . ' : ' . TITLE_AUTH_ERROR, explode("\n", TEXT_AUTH_ERROR) ) 
				);
			}
		
		return $this->session->auth_page_show( $plugin_cookies, $this, $add_params );
	}
}
?>
