<?php
require_once 'language.php';

require_once 'lib/default_dune_plugin.php';
require_once 'lib/default_archive.php';
require_once 'lib/tv/tv_group_list_screen.php';
require_once 'lib/tv/tv_channel_list_screen.php';
require_once 'lib/tv/tv_favorites_screen.php';
require_once 'lib/vod/vod_list_screen.php';
require_once 'lib/vod/vod_search_screen.php';
require_once 'lib/vod/vod_genres_screen.php';
require_once 'lib/vod/vod_movie_screen.php';
require_once 'lib/vod/vod_series_list_screen.php';
require_once 'lib/vod/vod_favorites_screen.php';

require_once 'izhcom_session.php'; 
require_once 'izhcom_entry_handler.php';
require_once 'izhcom_tv.php';
require_once 'izhcom_vod.php';
require_once 'izhcom_setup_screen.php';
require_once 'izhcom_vod_root_screen.php';
require_once 'izhcom_vod_list_screen.php';

class IzhcomPlugin extends DefaultDunePlugin {
    private $entry_handler;
    private $purchase_handler;
    private $session;

    public function __construct() {
    	$this->session = new IzhcomSession($this);
        $this->entry_handler = new IzhcomEntryHandler($this->session);
        $this->purchase_handler = new IzhcomPurchaseHandler($this->session);

        $this->tv = new IzhcomTv($this->session);
		$this->vod = new IzhcomVod($this->session, $this->purchase_handler);
		
		$this->add_screen( new TvGroupListScreen($this->tv, $this->get_tv_folder_views('cats')) );
		$this->add_screen( new TvChannelListScreen($this->tv, $this->get_tv_folder_views('channels')) );
		$this->add_screen( new IzhcomSetupScreen($this->session, $this->entry_handler) );
		
		$this->add_screen( new IzhcomVodRootScreen($this->session, $this->get_tv_folder_views('vod')) );
		
		$this->add_screen( new IzhcomVodListScreen($this->session, $this->vod));
		$this->add_screen( new VodMovieScreen($this->vod));
		$this->add_screen( new VodSeriesListScreen($this->vod) );
		$this->add_screen( new VodFavoritesScreen($this->vod) );
		$this->add_screen( new VodSearchScreen($this->vod) );
		$this->add_screen( new VodGenresScreen($this->vod) );
    }

    function unset_login() {
    	$this->tv->unload_channels();
    	$this->vod->clear_movie_cache();
    	$this->vod->clear_genre_cache();
    	
    	DefaultArchive::clear_cache();
    }
    
    private function get_tv_folder_views($what) {
    	switch($what) {
    	case 'vod':
    	   	return array(
            	array
	            (
    	            PluginRegularFolderView::async_icon_loading => true,
    	            
	                PluginRegularFolderView::view_params => array
    	            (
            	        ViewParams::num_cols => 5,
        	            ViewParams::num_rows => 3,
	                    ViewParams::icon_selection_box_width => 225,
    	                ViewParams::icon_selection_box_height => 225,
        	            ViewParams::icon_selection_box_dy => -112,
	                ),

	                PluginRegularFolderView::base_view_item_params => array
    	            (
        	            ViewItemParams::icon_valign => VALIGN_CENTER,
	                    ViewItemParams::item_paint_caption => false,
    	                ViewItemParams::icon_scale_factor => 1.25,
        	            ViewItemParams::icon_sel_scale_factor => 1.5,
	                ),

	                PluginRegularFolderView::not_loaded_view_item_params => array
    	            (
        	            ViewItemParams::icon_path => 'plugin_file://images/unknown.png',
	                    ViewItemParams::item_paint_caption_within_icon => true,
    	                ViewItemParams::item_caption_within_icon_color => 'black',
        	        ),
				),
			);
    	case 'cats':
        	return array(
            	array
	            (
    	            PluginRegularFolderView::async_icon_loading => true,
    	            
	                PluginRegularFolderView::view_params => array
    	            (
            	        ViewParams::num_cols => 5,
        	            ViewParams::num_rows => 3,
	                    ViewParams::icon_selection_box_width => 225,
    	                ViewParams::icon_selection_box_height => 225,
        	            ViewParams::icon_selection_box_dy => -112,
	                ),

	                PluginRegularFolderView::base_view_item_params => array
    	            (
        	            ViewItemParams::icon_valign => VALIGN_CENTER,
	                    ViewItemParams::item_paint_caption => false,
    	                ViewItemParams::icon_scale_factor => 1.25,
        	            ViewItemParams::icon_sel_scale_factor => 1.5,
	                ),

	                PluginRegularFolderView::not_loaded_view_item_params => array
    	            (
        	            ViewItemParams::icon_path => 'plugin_file://images/unknown.png',
	                    ViewItemParams::item_paint_caption_within_icon => true,
    	                ViewItemParams::item_caption_within_icon_color => 'black',
        	        ),
				),
			);
		case 'channels':
			return array(
				array
				(
		            PluginRegularFolderView::async_icon_loading => true,
    	            
	                PluginRegularFolderView::view_params => array
    	            (
            	        ViewParams::num_cols => 5,
        	            ViewParams::num_rows => 3,
	                    ViewParams::icon_selection_box_width => 225,
    	                ViewParams::icon_selection_box_height => 225,
        	            ViewParams::icon_selection_box_dy => -112,
	                ),

	                PluginRegularFolderView::base_view_item_params => array
    	            (
        	            ViewItemParams::icon_valign => VALIGN_CENTER,
	                    ViewItemParams::item_paint_caption => false,
    	                ViewItemParams::icon_scale_factor => 1.7,
        	            ViewItemParams::icon_sel_scale_factor => 1.9,
	                ),

	                PluginRegularFolderView::not_loaded_view_item_params => array
    	            (
        	            ViewItemParams::icon_path => 'plugin_file://images/empty-tv.png',
	                    ViewItemParams::item_paint_caption_within_icon => true,
    	                ViewItemParams::item_caption_within_icon_color => 'black',
        	        ),
				),
			);
		}
    }
}
?>
