<?php

//require_once 'language.php';

class C {
	const IZHCOM_AUTH 			= 'http://vod.izhcom.net/dune/auth.php';
	const IZHCOM_TV_INFO		= 'http://vod.izhcom.net/dune/tv_info.php';
	const IZHCOM_EPG_INFO		= 'http://vod.izhcom.net/dune/epg_info.php?channel_id=%d&day_start_ts=%d';
	
	const IZHCOM_MOVIE_RTSP		= 'rtsp://91.208.84.19/%s';
	
	const IZHCOM_MOVIE_POSTER	= 'http://vod.izhcom.net/_img/vodCoversBig/%s';
	const IZHCOM_MOVIES_LIST	= 'http://vod.izhcom.net/dune/movies_list.php?type=%s&page=%s&nums=%s';
	const IZHCOM_MOVIE_INFO		= 'http://vod.izhcom.net/dune/movie_info.php?movie_id=%d';
	const IZHCOM_MOVIE_PURCHASE = 'http://vod.izhcom.net/dune/movie_purchase.php?movie_id=%d&check=%s';
	const IZHCOM_LOAD_FAVORITES = 'http://vod.izhcom.net/dune/favorites.php';
	const IZHCOM_SAVE_FAVORITES = 'http://vod.izhcom.net/dune/favorites.php?ids=%s';
	
	const IZHCOM_GENRES_INFO 	= 'http://vod.izhcom.net/dune/genres_info.php';
	
	const IZHCOM_ARCHIVE		= 'http://vod.izhcom.net/dune/images';
	const IZHCOM_ARCHIVE_ID		= 'main';
}

class IzhcomSession {

	private $logged_in = false;
	private $http_opts = null;
	private $sid = null;
	private $sid_name = null;

	private $unset_login_listener = null;

    public function __construct($unset_login_listener) {
        $this->http_opts = array (
            CURLOPT_FOLLOWLOCATION  => true,
            CURLOPT_MAXREDIRS       => 10,
            CURLOPT_COOKIEFILE      => '/tmp/izhcom.cookies',
            CURLOPT_COOKIEJAR       => '/tmp/izhcom.cookies'
        );
        
        $this->unset_login_listener = $unset_login_listener;
    }

    public function remote_call( $remote_url, $xml_top_node, &$plugin_cookies, $reauth = false ) {
		$this->check_logged_in( $plugin_cookies, $reauth );
	
		try {
	    	$content = $this->http_get_document( $remote_url );

    	    $xml = simplexml_load_string($content);

	        if ($xml === false) {
    	    	hd_print(__FUNCTION__ . ": error: can't parse XML document.");
				hd_print("XML-text: $content");
				throw new Exception('Illegal XML document');
			}
			if($xml->getName() != $xml_top_node) {
				hd_print(__FUNCTION__ . ": error: unexpected node '" . $xml->getName() . "'. Expected: '$xml_top_node'");
				throw new Exception('Invalid XML document');
			}
			$exitcode = isset($xml->exitcode) ? (int)$xml->exitcode : -999;
	        if( $exitcode != 0 ) {
    	    	if($reauth == false && $exitcode == -2 ) {
	       			// Server side session possible destroyed. Try reactivate once.
    	   			return( $this->remote_call($remote_url, $xml_top_node, $plugin_cookies, true) );
				}
    	    	hd_print(__FUNCTION__ . ": $xml_top_node error (" . $xml->exitcode . '), ' . $xml->message);
	        	throw new Exception("Server $xml_top_node error");
			}
		} catch ( Exception $e ) {
			throw new DuneException(
				'Server Error', -1,
				ActionFactory::show_error( true, TEXT_IZHTV_TITLE . ' : ' . TITLE_SERVER_ERROR, explode("\n", TEXT_SERVER_ERROR ) )
			);
		}
		
		return($xml);
    }

    public function http_get_document($url) {
    	if($this->sid) {
    		if( ($pos = strpos($url, '?')) === false ) 
    			$url .= '?';
			else 
			if( $pos < strlen($url) - 1 ) $url .= '&';
    		
    		$url .= $this->sid_name . '=' . $this->sid;
    		
    		hd_print(__FUNCTION__ . ' : ' . $url);
		}
    	return( HD::http_get_document($url, $this->http_opts) );
    }

    public function http_post_document($url, $post_data) {
    	$opts = $this->http_opts;
    	$opts[CURLOPT_POST] = true;
    	$opts[CURLOPT_TIMEOUT] = 20;
    	if($this->sid_name)
    		$post_data[$this->sid_name] = $this->sid;
    	$opts[CURLOPT_POSTFIELDS] = $post_data;
    	
    	try {
    		$cont = HD::http_get_document($url, $opts);
		} catch( Exception $e ) {
			$cont = '';
		};
		return( $cont );
    }

    private function auth_page_defs( &$plugin_cookies, $handler, $add_params ) {
        $defs = array();

        $auth_id = isset($plugin_cookies->auth_id) ? $plugin_cookies->auth_id : '';
        $auth_pin = isset($plugin_cookies->auth_pin) ? $plugin_cookies->auth_pin : '';

        ControlFactory::add_text_field($defs,
            $handler, $add_params,
            'auth_id', TEXT_LOGIN,
            $auth_id, true, false, false, false, 500);

        ControlFactory::add_text_field($defs,
            $handler, $add_params,
            'auth_pin', TEXT_PASSWORD,
            $auth_pin, true, false, false, false, 500);

        ControlFactory::add_vgap($defs, 50);

        ControlFactory::add_button($defs,
            $handler, $add_params,
            'auth_proceed', null, TEXT_ENTER, 300);

        ControlFactory::add_vgap($defs, -3);

        ControlFactory::add_close_dialog_button($defs,
            TEXT_CANCEL, 300);

        return ($defs);
    }

    public function check_logged_in(&$plugin_cookies = null, $reauth = false) {
    	$user_input = null;
    	if($reauth) $this->logged_in = false;
		$r = $this->do_auth($user_input, $plugin_cookies, $state);
		if( $r == false ) exit;
//			throw new DuneException(
//				'Reauth needed', -1,
//			     ActionFactory::show_error(true, TEXT_IZHTV_TITLE . ' : ' . TITLE_AUTH_ERROR, explode("\n", TEXT_AUTH_ERROR) )
//			);
	}

    public function is_logged_in() {
    	return($this->logged_in);
    }

    public function logout(&$plugin_cookies) {
    	$this->logged_in = false;
    	if( isset($plugin_cookies) && isset($plugin_cookies->auth_id) )
    		$plugin_cookies->auth_id = $plugin_cookies->auth_pin = '';
    		
		$this->unset_login_listener->unset_login();
    }

    private function do_server_login($auth_id, $auth_pin, $auto_login = false) {
    	$post_data = array( 'auth_id' => $auth_id, 'auth_pin' => $auth_pin, 'auto_login' => ($auto_login ? 1 : 0) );
   		$content = $this->http_post_document(C::IZHCOM_AUTH, $post_data);

		if(!$content) throw new Exception('No server connection');

    		$xml = simplexml_load_string($content);
			if ($xml === false) {
				hd_print(__FUNCTION__ . ": error: can't parse XML document.");
				hd_print("XML-text: $doc.");
    		    throw new Exception('Illegal XML document');
			}
			if($xml->getName() != 'auth_info') {
				hd_print(__FUNCTION__ . ": error: unexpected node '" . $xml->getName() . "'. Expected: 'auth_info'");
				throw new Exception('Invalid XML document');
			}
			if( !isset($xml->exitcode) || $xml->exitcode != 0 ) {
				hd_print(__FUNCTION__ . ': authentication error (' . $xml->exitcode . '), ' . $xml->message);
				throw new Exception('Server auth error');
			}
			$this->sid_name = $xml->sid_name;
			$this->sid = $xml->sid;
			hd_print( __FUNCTION__ . ': ' . $this->sid_name . ' = ' . $this->sid );
    }

    private function do_login(&$plugin_cookies, $auto_login = false) {
    	if (!isset($plugin_cookies->auth_id))
    		throw new Exception('User name is empty');
    		
		$this->do_server_login( $plugin_cookies->auth_id, $plugin_cookies->auth_pin, $auto_login );
    }

    public function do_auth(&$user_input, &$plugin_cookies, &$state) {

    	$state = 0; // Ok

    	$auto_login = true;

    	if($this->logged_in == true) return(true);

		if( $user_input && isset($user_input->control_id) && $user_input->control_id == 'auth_proceed' ) {
			if( $user_input->auth_id === '' || $user_input->auth_pin === '' ) return (false);
			$auto_login = false;
			$plugin_cookies->auth_id = $user_input->auth_id;
			$plugin_cookies->auth_pin = $user_input->auth_pin;
		}
		
    	if( !isset($plugin_cookies->auth_id) || $plugin_cookies->auth_id === ''
    		|| !isset($plugin_cookies->auth_pin) || $plugin_cookies->auth_pin === '' ) return( false );
    
/*    	if( !isset($plugin_cookies->auth_id) || $plugin_cookies->auth_id === '' ) {

			if (!isset($user_input->control_id) || $user_input->control_id != 'auth_proceed')
				return (false);

			if ($user_input->auth_id === '') return (false);

			$plugin_cookies->auth_id = $user_input->auth_id;
			$plugin_cookies->auth_pin = $user_input->auth_pin;
		} */

		try {
			$this->do_login( $plugin_cookies, $auto_login );
		} catch(Exception $e) {
			$state = -2;
			if( $e->getMessage() == 'No server connection' ) $state = -4;
			else
				$this->logout($plugin_cookies);
			return( false );
		}

		$this->logged_in = true;
				
		return( true );
    }

    public function auth_page_show( &$plugin_cookies, $handler, $add_params = null ) {
        return 
        		ActionFactory::show_dialog(
    	     	   TEXT_IZHTV_ENTER,
    	     	   $this->auth_page_defs( $plugin_cookies, $handler, $add_params ),
    	     	   true
    	     	);
    }
    
    public function get_icon($id) {
    	$archive = $this->get_archive();
/*		$archive = DefaultArchive::get_archive(
        	C::IZHCOM_ARCHIVE_ID,
        	C::IZHCOM_ARCHIVE
		); */
		return $archive->get_archive_url($id);
	}
	
	public function get_archive() {
		$archive = DefaultArchive::get_archive(
			C::IZHCOM_ARCHIVE_ID, 
			C::IZHCOM_ARCHIVE
		);
		$def = $archive->get_archive_def();
		if( $def[PluginArchiveDef::total_size] == 0 ) {
			DefaultArchive::clear_cached_archive( C::IZHCOM_ARCHIVE_ID );
			return DefaultArchive::get_archive(
				C::IZHCOM_ARCHIVE_ID, 
				C::IZHCOM_ARCHIVE
			);
		}
		
		return( $archive );
	}
	
	public function api_get_stream_url($playback_url) {
		$this->check_logged_in();
		
		if (substr($playback_url, 0, 12) === 'http://ts://')
			$playback_url = 'http://' . substr($playback_url, 12);
			
		return($playback_url);
	}
	
	public function load_genres(&$plugin_cookies) {
		try {
			$xml = $this->remote_call( C::IZHCOM_GENRES_INFO, 'genres_info', $plugin_cookies );
		
			$genres = array();
			for($i = 0; $i < count($xml->genre); ++$i) {
				$genres[intval($xml->genre[$i]->id)] = strval($xml->genre[$i]->name);
			}
		} catch( Exception $e) {};
		                              
      	return( $genres );
	}
	
	public function load_movie($movie_id, &$plugin_cookies) {
		$movie = new Movie($movie_id);
		
		try {
	    	$xml = $this->remote_call(  sprintf(C::IZHCOM_MOVIE_INFO, $movie_id), 'movie_info', $plugin_cookies);

    	    $poster_url = sprintf( C::IZHCOM_MOVIE_POSTER, strval($xml->poster) );

	        $movie->set_data(
    	        $xml->name,
        	    $xml->name_orig,
	            $xml->description,
    	        $poster_url,
        	    $xml->length,
	            $xml->year,
    	        $xml->director,
        	    $xml->scenario,
	            $xml->actors,
    	        $xml->genre_str,
        	    $xml->rate_imdb,
	            $xml->rate_kinopoisk,
    	        $xml->rate_mpaa,
        	    $xml->country,
	            $xml->budget
			);
		
//        $playback_url = sprintf( C::IZHCOM_MOVIE_RTSP, strval($xml->filename) );
        
        	$playback_url = sprintf( C::IZHCOM_MOVIE_RTSP, strval($xml->id) );

        	hd_print(__FUNCTION__ . ': ' . $playback_url);

			$movie->add_series_data( $xml->id, $xml->name, $playback_url, false );
			
		} catch( Exception $e) {};
		        
		return($movie);
    }

    public function movies_list_last( $page, $nums, &$plugin_cookies ) {
        return $this->movies_list('last', null, null, $page, $nums, $plugin_cookies);
    }

    public function movies_list_best( $page, $nums, &$plugin_cookies ) {
        return $this->movies_list('best', null, null, $page, $nums, $plugin_cookies);
    }

    public function movies_list_search( $query, $page, $nums, &$plugin_cookies ) {
        return $this->movies_list('text', $query, null, $page, $nums, $plugin_cookies);
    }

    public function movies_list_genres( $genre, $page, $nums, &$plugin_cookies ) {
        return $this->movies_list('genre', null, $genre, $page, $nums, $plugin_cookies);
    }

    public function movies_list( $type, $query, $genre, $page, $nums, &$plugin_cookies ) {
    	$url = sprintf( C::IZHCOM_MOVIES_LIST, $type, $page, $nums );
    	if ($genre !== null) $url .= "&genre=$genre";
		if ($query !== null) $url .= "&query=$query";
	
		$xml = '';
		try {
			$xml = $this->remote_call($url, 'movies_list', $plugin_cookies);
		} catch( Exception $e) {};
		
		return ($xml);
	}
	
	public function purchase_content( $movie_id, $check_only, &$plugin_cookies ) {
		try {
			$xml = $this->remote_call( 
				sprintf( C::IZHCOM_MOVIE_PURCHASE, $movie_id, ($check_only ? '1' : '0') ), 
				'movie_purchase', $plugin_cookies 
			);
			if( !is_numeric( strval($xml->status) ) ) return(false);
		} catch( Exception $e) { 
			return(false); 
		};
		
		return( intval($xml->status) );
	}
	
	public function load_favorites( &$plugin_cookies ) {
		$movies = array();
		try {
			$xml = $this->remote_call( C::IZHCOM_LOAD_FAVORITES, 'favorites', $plugin_cookies );

			for($i = 0; $i < count($xml->favorite); ++$i) {
				$movies[] = intval($xml->favorite[$i]->id);
			}
		} catch( Exception $e) {};
		
		return( $movies );
	}

	public function save_favorites(&$fav_movie_ids, &$plugin_cookies) {
		$data = '';
		for($i = 0; $i < count($fav_movie_ids); ++$i ) {
			if($data) $data .= ':';
			$data .= (int)$fav_movie_ids[$i]; 
		}
		try {
			$xml = $this->remote_call( sprintf(C::IZHCOM_SAVE_FAVORITES, $data), 'favorites', $plugin_cookies );
		} catch( Exception $e) {};
	}
	
}
?>
