<?php
require_once 'lib/vod/abstract_vod.php';
require_once 'lib/vod/movie.php';

class IzhcomVod extends AbstractVod {
    private $session;
    private $handler;

    public function __construct($session, $handler) {
        $this->session = $session;
        $this->handler = $handler;
        parent::__construct(true, true, false);
    }

    private function purchase_page_defs( $handler, $cost ) {
        $defs = array();

        ControlFactory::add_label($defs, '', sprintf(TEXT_NEED_PURCHASE, $cost) );
        
        ControlFactory::add_close_dialog_button($defs, TEXT_CANCEL, 300);
        
        ControlFactory::add_button($defs,
            $handler, array(), 'make_purchase', null, TEXT_PURCHASE, 300);
        
        return ($defs);
    }

    public function get_vod_info(MediaURL $media_url, &$plugin_cookies) {
    	$this->session->check_logged_in($plugin_cookies);
    	
    	$plugin_cookies->current_movie_id = $media_url->movie_id;
    	$status = $this->session->purchase_content( $media_url->movie_id, true, $plugin_cookies );

    	hd_print(__FUNCTION__ . ": status="  . $status);
    	
    	if($status === 0) {
    		// Purchased successfully early, or film cost is 0 roubles
    		// Nothing to do here. But show must go on.
    	} elseif( $status > 0 ) { // not purchased, used $status as cost
    		$plugin_cookies->current_movie_id = $media_url->movie_id;
			throw
    			new DuneException(
    				'Purchase needed', 0, 
    				ActionFactory::show_dialog(
    	     	   		TEXT_PURCHASE,
						$this->purchase_page_defs( $this->handler, $status ),
						true 
					)
				);
		} elseif($status == -10) { // movie not found
			$this->set_failed_movie_id( $media_url->movie_id );
    		throw
    			new DuneException(
    				'No movie error', 0, 
    				ActionFactory::show_error( false, TEXT_IZHTV_TITLE . ' : ' . TITLE_SERVER_ERROR, array(TEXT_MOVIE_NOT_FOUND) )
				);
    	
    	} elseif($status == -11) { //  no money
    		throw
    			new DuneException(
    				'Fatal error', 0, 
    				ActionFactory::show_error( false, TEXT_IZHTV_TITLE, array(TEXT_NO_MONEY) )
				);    		
    	} else { // default error hanler
    		throw
    			new DuneException(
    				'Fatal error', 0, 
    				ActionFactory::show_error( false, TEXT_IZHTV_TITLE . ' : ' . TITLE_SERVER_ERROR, explode("\n", TEXT_NO_CONNECTION) ) 
				);
    	}
    	
		
        return parent::get_vod_info($media_url, $plugin_cookies);
    }

    public function get_buffering_ms() {
    	return 3000;
    }

    public function get_vod_stream_url($playback_url, &$plugin_cookies) {
    	return $this->session->api_get_stream_url($playback_url);
	}

    public function get_archive(MediaURL $media_url) {
        return $this->session->get_archive();
    }

    public function folder_entered(MediaURL $media_url, &$plugin_cookies) {
        $this->session->check_logged_in($plugin_cookies);
    }

    public function get_genre_icon_url($genre_id) {
        return $this->session->get_icon('mov_genre_default.png');
    }

    public function get_genre_media_url_str($genre_id) {
        return IzhcomVodListScreen::get_media_url_str('genres', $genre_id);
    }

    public function get_search_media_url_str($pattern) {
        return IzhcomVodListScreen::get_media_url_str('search', $pattern);
    }
    
    public function try_load_movie($movie_id, &$plugin_cookies) {
    	$movie = $this->session->load_movie($movie_id, $plugin_cookies);
		$this->set_cached_movie($movie);
    }
    
    protected function load_genres(&$plugin_cookies) {
      	return( $this->session->load_genres($plugin_cookies) );
	}

	protected function load_favorites(&$plugin_cookies) {
		$movies = $this->session->load_favorites($plugin_cookies);
		for($i = 0; $i < count($movies); ++$i) {
			$this->ensure_movie_loaded($movies[$i], $plugin_cookies);
		}
		$this->set_fav_movie_ids( $movies );
	}
	
	protected function do_save_favorite_movies(&$fav_movie_ids, &$plugin_cookies) {
		$movies = $this->session->save_favorites($fav_movie_ids, $plugin_cookies);
	}
    
    
//////////// VIEWS 
  
	public function get_vod_genres_folder_views() {
        $mov_genre_default_icon_url =
            $this->session->get_icon('mov_genre_default.png');
        return array(
            array
            (
                PluginRegularFolderView::async_icon_loading => false,

                PluginRegularFolderView::view_params => array
                (
                    ViewParams::num_cols => 3,
                    ViewParams::num_rows => 10,
#                    ViewParams::content_box_padding_bottom => 110,
                ),

                PluginRegularFolderView::base_view_item_params => array
                (
                    ViewItemParams::item_padding_top => 0,
                    ViewItemParams::item_padding_bottom => 0,
                    ViewItemParams::icon_valign => VALIGN_CENTER,
                    ViewItemParams::item_layout => HALIGN_LEFT,
                    ViewItemParams::item_caption_width => 365,
                    ViewItemParams::icon_dx => 65,
                ),

                PluginRegularFolderView::not_loaded_view_item_params => array
                (
                    ViewItemParams::icon_path => $mov_genre_default_icon_url,
//                    ViewItemParams::item_paint_caption_within_icon => true,
//					ViewItemParams::item_caption_within_icon_color => 'black',
                ),
            ));
    }

    public function get_vod_list_folder_views() {
        $mov_unset_url = $this->session->get_icon('mov_unset.png');

        return array(
            array
            (
                PluginRegularFolderView::async_icon_loading => true,

                PluginRegularFolderView::view_params => array
                (
                    ViewParams::num_cols => 6,
                    ViewParams::num_rows => 3,
//                    ViewParams::icon_selection_box_width => 160,
//                    ViewParams::icon_selection_box_height => 232,
                    ViewParams::icon_selection_box_width => 170,
                    ViewParams::icon_selection_box_height => 270,
                    ViewParams::paint_details => true,
                    ViewParams::zoom_detailed_icon => true,
                ),

                PluginRegularFolderView::base_view_item_params => array
                (
                    ViewItemParams::item_padding_top => 0,
                    ViewItemParams::item_padding_bottom => 0,
                    ViewItemParams::icon_valign => VALIGN_CENTER,
                    ViewItemParams::icon_width => 145,
                    ViewItemParams::icon_height => 217,
                    ViewItemParams::item_paint_caption => false,
                    ViewItemParams::icon_scale_factor => 1.0,
                    ViewItemParams::icon_sel_scale_factor => 1.2,
                ),

                PluginRegularFolderView::not_loaded_view_item_params => array
                (
                    ViewItemParams::icon_path => $mov_unset_url,
                    ViewItemParams::item_detailed_icon_path => 'missing://',
//                    ViewItemParams::item_paint_caption_within_icon => true,
//					ViewItemParams::item_caption_within_icon_color => 'black',
                ),
            ));
    }
                                                         
}
?>
